@@ -11,8 +11,8 @@ from rl_plotter import plot_utils as pu
 
 def main():
 	parser = argparse.ArgumentParser(description='plotter')
-	parser.add_argument('--fig_length', type=int, default=6, 
-						help='matplotlib figure length (default: 6)')
+	parser.add_argument('--fig_length', type=int, default=8, 
+						help='matplotlib figure length (default: 8)')
 	parser.add_argument('--fig_width', type=int, default=6, 
 						help='matplotlib figure width (default: 6)')
 	parser.add_argument('--style', default='seaborn',
@@ -21,14 +21,16 @@ def main():
 						help='matplotlib figure title (default: None)')
 	parser.add_argument('--xlabel', default=None,
 						help='matplotlib figure xlabel')
-	parser.add_argument('--xkey', default='l',
+	parser.add_argument('--xkey', default='total_steps',
 						help='x-axis key in csv file (default: l)')
-	parser.add_argument('--ykey', default='r',
-						help='y-axis key in csv file (default: r)')
+	parser.add_argument('--ykey', default=['mean_score'], nargs='+',
+						help='y-axis key in csv file (support multi) (default: r)')
+	parser.add_argument('--yduel', action='store_true',
+						help='=duel y axis (use if has two ykeys)')
 	parser.add_argument('--ylabel', default=None,
 						help='matplotlib figure ylabel')
-	parser.add_argument('--smooth', type=int, default=10,
-					help='smooth radius of y axis (default: 10)')
+	parser.add_argument('--smooth', type=int, default=5,
+					help='smooth radius of y axis (default: 5)')
 	parser.add_argument('--resample', type=int, default=512,
 						help='if not zero, size of the uniform grid in x direction to resample onto. Resampling is performed via symmetric EMA smoothing (see the docstring for symmetric_ema). Default is zero (no resampling). Note that if average_group is True, resampling is necessary; in that case, default value is 512. (default: 512)')
 	parser.add_argument('--smooth_step', type=float, default=1.0,
@@ -43,24 +45,30 @@ def main():
 						help='location of legend')
 	parser.add_argument('--legend_outside', action='store_true',
 						help='place the legend outside of the figure')
+	parser.add_argument('--borderpad', type=float, default=0.5,
+						help='borderpad of legend (default: 0.5)')
+	parser.add_argument('--labelspacing', type=float, default=0.5,
+						help='labelspacing of legend (default: 0.5)')
 	parser.add_argument('--no_legend_group_num', action='store_true',
 						help="don't show num of group in legend")
 	
 	parser.add_argument('--time', action='store_true',
-						help='enable this will set x_key to t, and activate parameters about time')
+						help='enable this will activate parameters about time')
 	parser.add_argument('--time_unit', default='h',
 						help='parameters about time, x axis time unit (default: h)')
 	parser.add_argument('--time_interval', type=float, default=1,
 						help='parameters about time, x axis time interval (default: 1)')
 
-	parser.add_argument('--xformat', default='eng',
+	parser.add_argument('--xformat', default='',
 						help='x-axis format')
 	parser.add_argument('--xlim', type=int, default=None,
 						help='x-axis limitation (default: None)')
 	
 	parser.add_argument('--log_dir', default='./',
 						help='log dir (default: ./)')
-	parser.add_argument('--filename', default='monitor',
+	parser.add_argument('--filters', default=[''], nargs='+',
+						help='filters of dirname')
+	parser.add_argument('--filename', default='evaluator',
 						help='csv filename')
 	parser.add_argument('--show', action='store_true',
 						help='show figure')
@@ -74,7 +82,6 @@ def main():
 	if args.time:
 		if args.xlabel is None:
 			args.xlabel = 'Training time'
-		args.xkey = 't'
 		if args.time_unit == 'h': 
 			xscale = 60 * 60
 			args.time_interval = 2
@@ -88,11 +95,25 @@ def main():
 	if args.ylabel is None:
 		args.ylabel = 'Episode Reward'
 
-	if args.filename == 'evaluator':
+	if '.' not in args.filename:
+		args.filename = args.filename + '.csv'
+	
+	# OpenAI Baseline's monitor
+	if args.filename == 'monitor.csv':
+		args.xkey = 'l'
+		args.ykey = ['r']
+	
+	# OpenAI spinup's progress
+	if args.filename == 'progress.txt' or args.filename == 'progress.csv':
+		args.xkey = 'TotalEnvInteracts'
+		args.ykey = ['AverageEpRet']
+	
+	# rl-plotter's evaluator
+	if args.filename == 'evaluator.csv':
 		args.xkey = 'total_steps'
-		args.ykey = 'mean_score'
+		args.ykey = ['mean_score']
 
-	allresults = pu.load_results(args.log_dir, filename=args.filename)
+	allresults = pu.load_results(args.log_dir, filename=args.filename, filters=args.filters)
 	pu.plot_results(allresults,
 		fig_length=args.fig_length,
 		fig_width=args.fig_width,
@@ -102,6 +123,7 @@ def main():
 		ylabel=args.ylabel,
 		xkey=args.xkey,
 		ykey=args.ykey,
+		yduel=args.yduel,
 		xscale=xscale,
 		smooth_radius=args.smooth,
 		resample=args.resample,
@@ -112,6 +134,8 @@ def main():
 		legend_outside=args.legend_outside,
 		legend_loc=args.legend_loc,
 		legend_group_num=not args.no_legend_group_num,
+		legend_borderpad=args.borderpad,
+		legend_labelspacing=args.labelspacing,
 		filename=args.filename)
 
 	ax = plt.gca() # get current axis
@@ -125,15 +149,20 @@ def main():
 		elif args.xformat == 'log':
 			ax.xaxis.set_major_formatter(mticker.LogFormatter())
 		elif args.xformat == 'sci':
-			ax.xaxis.set_major_formatter(mticker.LogFormatterSciNotation())
+			#ax.xaxis.set_major_formatter(mticker.LogFormatterSciNotation())
+			plt.ticklabel_format(style='sci', axis='x', scilimits=(0,0), useMathText=True)
+		else:
+			plt.ticklabel_format(style='sci', axis='x', scilimits=(0,0), useMathText=False)
 
 	if args.xlim is not None:
 		plt.xlim((0, args.xlim))
-	
+
 	if args.save:
 		plt.savefig(args.log_dir + 'figure', dpi=args.dpi, bbox_inches='tight')
 	if args.show:
 		plt.show()
+	
+	
 
 
 if __name__ == "__main__":
